@@ -87,7 +87,7 @@ def processingFailed(reason, request, ctx):
         log.err("Original exception:", isErr=1)
         log.err(reason)
         request.write("<html><head><title>Internal Server Error</title></head>")
-        request.write("<body><h1>Internal Server Error</h1>An error occurred rendering the requested page. Additionally, an error occured rendering the error page.</body></html>")
+        request.write("<body><h1>Internal Server Error</h1>An error occurred rendering the requested page. Additionally, an error occurred rendering the error page.</body></html>")
         request.finishRequest( False )
 
     return errorMarker
@@ -362,7 +362,7 @@ class OldResourceAdapter(object):
     def renderHTTP(self, ctx):
         request = inevow.IRequest(ctx)
         if self.real_prepath_len is not None:
-            path = request.postpath = request.prepath[self.real_prepath_len:]
+            request.postpath = request.prepath[self.real_prepath_len:]
             del request.prepath[self.real_prepath_len:]
         result = defer.maybeDeferred(self.original.render, request).addCallback(
             self._handle_NOT_DONE_YET, request)
