@@ -1,8 +1,9 @@
-# Copyright (c) 2004 Divmod.
+# -*- test-case-name: nevow -*-
+# Copyright (c) 2004-2009 Divmod.
 # See LICENSE for details.
 
-
-"""Nevow interface definitions.
+"""
+Nevow interface definitions.
 """
 
 from zope.interface import Interface, Attribute
@@ -61,8 +62,16 @@ class IQ(Interface):
 
 class IResource(Interface):
     def locateChild(ctx, segments):
-        """Locate another object which can be adapted to IResource
-        Return a tuple of resource, path segments
+        """
+        Locate another object which can be adapted to IResource.
+
+        @param ctx: The context object for the request being responded to.
+        @param segments: A tuple of strings giving the remaining query segments
+            to resolve into an IResource.
+
+        @return: A two-tuple of an L{IResource} provider and a tuple giving the
+            query segments which remain to be processed.  A L{Deferred} which
+            is called back with such a two-tuple may also be returned.
         """
 
     def renderHTTP(ctx):
@@ -79,6 +88,34 @@ class IRenderer(Interface):
         """
 
 
+class IRenderable(Interface):
+    def renderer(name):
+        """
+        Return the render function associated with the given name.
+
+        @type name: C{str}
+        @param name: The value of a render directive encountered in the
+            document returned by a call to L{IRenderable.render}.
+
+        @return: A two-argument callable which will be invoked with the request
+            being responded to and the tag object on which the render directive
+            was encountered.
+        """
+
+
+    def render(request):
+        """
+        Get the document for this L{IRenderable}.
+
+        @type request: L{IRequest} provider or L{NoneType}
+        @param request: The request in response to which this method is being
+            invoked.
+
+        @return: An object which can be flattened.
+        """
+
+
+
 class IRendererFactory(Interface):
     """A renderer factory is capable of taking a renderer directive (a string)
     and returning a callable which when called, will render a portion of DOM.
@@ -204,20 +241,24 @@ class IComponentized(Interface):
         @return: a list of the interfaces that were removed.
         """
 
+
+
 class ISession(IComponentized):
-    """A web session
+    """
+    A web session
 
     You can locate a Session object to represent a unique web session using
     ISession(ctx). This default session implementation uses cookies to
     store a session identifier in the user's browser.
 
-    uid: Session uid
-
     TODO: Need better docs; what's a session and why and how do you use it
     """
 
+    uid = Attribute("The unique identifier for this session.")
+
     def setLifetime(lifetime):
-        """Set the approximate lifetime of this session, in seconds.
+        """
+        Set the approximate lifetime of this session, in seconds.
 
         This is highly imprecise, but it allows you to set some general
         parameters about when this session will expire.  A callback will be
@@ -228,17 +269,25 @@ class ISession(IComponentized):
         attribute in class guard.SessionWrapper
         """
 
+
     def notifyOnExpire(callback):
-        """Call this callback when the session expires or logs out.
         """
+        Call this callback when the session expires or logs out.
+        """
+
 
     def expire():
-        """Expire/logout of the session.
+        """
+        Expire/logout of the session.
         """
 
+
     def touch():
-        """Refresh the session
         """
+        Refresh the session
+        """
+
+
 
 class IGuardSession(ISession):
     """ A web session base interface
@@ -263,8 +312,19 @@ class IRequest(IComponentized):
     @type args: A mapping of strings (the argument names) to lists of values.
                 i.e., ?foo=bar&foo=baz&quux=spam results in
                 {'foo': ['bar', 'baz'], 'quux': ['spam']}.
-    @ivar received_headers: All received headers
+    @ivar received_headers: All received headers.
     """
+    method = Attribute("The HTTP method that was used.")
+    uri = Attribute("The full URI that was requested (includes arguments).")
+    path = Attribute("The path only (arguments not included).")
+    prepath = Attribute("Path segments that have already been handled.")
+    postpath = Attribute("Path segments still to be handled.")
+    args = Attribute("All of the arguments, including URL and POST arguments.")
+    received_headers = Attribute("All received headers.")
+    deferred = Attribute("Fired once request processing is finished.")
+    client = Attribute("The client that sent this request.")
+    content = Attribute("File-like object containing the request body.")
+
     # Methods for received request
     def getHeader(key):
         """Get a header that was sent from the network.
@@ -420,6 +480,17 @@ class IRequest(IComponentized):
         This method is experimental.
         """
 
+
+    def notifyFinish(success):
+        """
+        Return a deferred that fires when the request is finished.
+
+        The deferred will fire with C{None} if the request finished
+        successfully, or with the error that caused it to be unsuccessful.
+        """
+
+
+
 class ISerializable(Interface):
     """DEPRECATED. Use nevow.flat.registerFlattener instead of registering
     an ISerializable adapter.
@@ -480,26 +551,15 @@ class IDocFactory(Interface):
     actually rendered.
     """
 
-    def load(ctx=None, preprocessors=()):
+    def load(ctx=None, preprocessors=(), precompile=None):
         """
         Load a template and return a stan document tree.
 
         @param preprocessors: An iterable of one-argument callables which will
-        be given the stan document tree to transform before it is compiled.
+            be given the stan document tree to transform before it is compiled.
         """
 
 
-class ISession(Interface):
-    """A web session
-
-    You can locate a Session object to represent a unique web session using
-    ctx.locate(ISession). This default session implementation uses cookies to
-    store a session identifier in the user's browser.
-
-    TODO: Need better docs; what's a session and why and how do you use it
-    """
-
-
 class IRemainingSegments(Interface):
     """During the URL traversal process, requesting this from the context
     will result in a tuple of the segments remaining to be processed.
@@ -565,17 +625,34 @@ class ILogger(Interface):
         """Write a log entry for this request."""
 
 
-class IJavascriptPackage(Interface):
-    """
-    Represents information about the filesystem layout of a set of
-    JavaScript modules.
 
-    @ivar mapping: A C{dict} mapping C{str} to C{str}.  The keys in
-    this dictionary are JavaScript module names which can be imported by
-    JavaScript files server by C{nevow.athena.LivePage}.  The values give
-    locations in the filesystem where the implementation of each module can
-    be found.
+class IFilesystemPackage(Interface):
     """
+    Represents information about the filesystem layout of a set of modules.
+    """
+    mapping = Attribute("""
+    A C{dict} mapping C{unicode} to C{str}.  The keys in this dictionary are
+    CSS or Javascript module names which can be imported by
+    L{nevow.athena.LivePage}.  The values give locations in the filesystem
+    where the implementation of each module can be found.
+    """)
+
+
+
+class IJavascriptPackage(IFilesystemPackage):
+    """
+    Represents information about the filesystem layout of a set of JavaScript
+    modules.
+    """
+
+
+
+class ICSSPackage(IFilesystemPackage):
+    """
+    Represents information about the filesystem layout of a set of CSS
+    modules.
+    """
+
 
 
 class IAthenaTransportable(Interface):
