@@ -55,24 +55,14 @@ Nevow.Athena.PageWidget.methods(
     },
 
     /**
-     * Bind this page's global event handlers to a window object.
+     * Construct an event handler function that dispatches to a method on
+     * self.
      */
-    function bindEvents(self, aWindow) {
-        var evts = ['onbeforeunload', 'onkeypress'];
-        for (var i = 0; i < evts.length; i++) {
-            Divmod.Base.addToCallStack(
-                aWindow, evts[i],
-                // This mess of nested functions is the easiest way to capture
-                // evts[i] and still get 'self' right in the inner function.
-                // Honest!
-                (function (evtName) {
-                    var thunk = function (evtObj) {
-                        return self[evtName](evtObj);
-                    };
-                    return thunk;
-                })(evts[i]),
-                false);
-        }
+    function makeHandler(self, evtName) {
+        var thunk = function (evtObj) {
+            return self[evtName](evtObj);
+        };
+        return thunk;
     },
 
     /**
@@ -309,7 +299,7 @@ Nevow.Athena.PageWidget.methods(
 
     /**
      * Display an error dialog to the user, containing some information
-     * about the uncaught error C{err}, which occured while trying to call
+     * about the uncaught error C{err}, which occurred while trying to call
      * the remote method C{methodName}.  To avoid this happening, errbacks
      * should be added synchronously to the deferred returned by L{callRemote}
      * (the errback that triggers this dialog is added via setTimeout(..., 0))
@@ -338,7 +328,7 @@ Nevow.Athena.PageWidget.methods(
         e.appendChild(titlebar);
 
         e.appendChild(
-            document.createTextNode("Your action could not be completed because an error occured."));
+            document.createTextNode("Your action could not be completed because an error occurred."));
 
 // Useful for debugging sometimes, except it really isn't very pretty.
 // toPrettyNode needs unit tests or something, though.
@@ -908,6 +898,7 @@ Nevow.Athena.Widget.methods(
     function addChildWidgetFromWidgetInfo(self, info) {
         return self._addChildWidgetFromComponents(
             info.requiredModules,
+            info.requiredCSSModules,
             info.id,
             info['class'],
             info.children,
@@ -920,7 +911,8 @@ Nevow.Athena.Widget.methods(
      * Actual implementation of dynamic widget instantiation.
      */
     function _addChildWidgetFromComponents(self,
-                                           requiredModules, widgetID,
+                                           requiredModules,
+                                           requiredCSSModules, widgetID,
                                            widgetClassName, children,
                                            initArguments, markup) {
 
@@ -948,6 +940,12 @@ Nevow.Athena.Widget.methods(
             throw new Error("You blew it.");
         }
 
+        for (var i = 0; i < requiredCSSModules.length; i++) {
+            /* we're doing this blindly; we don't know when this will
+             * complete, but it doesn't matter hugely */
+            Divmod.Runtime.theRuntime.loadStylesheet(requiredCSSModules[i]);
+        }
+
         importDeferreds = [];
         for (moduleIndex = 0; moduleIndex < requiredModules.length; ++moduleIndex) {
             moduleName = requiredModules[moduleIndex][0];
@@ -957,17 +955,22 @@ Nevow.Athena.Widget.methods(
             moduleObj = Divmod._global;
 
             for (var i = 0; i < moduleParts.length; ++i) {
-                if (moduleObj[moduleParts[i]] === undefined) {
-                    moduleObj[moduleParts[i]] = {};
+                var partName = moduleParts[i];
+                if (moduleObj[partName] === undefined) {
+                    moduleObj[partName] = {
+                        '__name__': moduleObj.__name__ + '.' + partName};
                 }
-                moduleObj = moduleObj[moduleParts[i]];
+                moduleObj = moduleObj[partName];
             }
 
             importDeferreds.push(
                 Divmod.Runtime.theRuntime.loadScript(
                     moduleURL));
         }
-        allImportsDone = Divmod.Defer.DeferredList(importDeferreds);
+        allImportsDone = Divmod.Defer.DeferredList(
+            importDeferreds,
+            /* fireOnOneCallback= */false,
+            /* fireOnOneErrback= */true);
         allImportsDone.addCallback(
             function(ignored) {
                 topNode = Divmod.Runtime.theRuntime.firstNodeByAttribute(
@@ -1446,16 +1449,6 @@ Nevow.Athena.Widget._instantiateWidgets = function() {
     }
 };
 
-Nevow.Athena.Widget._initialize = function() {
-    Divmod.debug("widget", "Instantiating live widgets");
-    Nevow.Athena.Widget._pageLoaded = true;
-    Nevow.Athena.Widget._instantiateWidgets();
-    Divmod.debug("widget", "Finished instantiating live widgets");
-};
-
-Divmod.Base.addLoadEvent(Nevow.Athena.Widget._initialize);
-
-
 /**
  * Initialize state in this module that only the server knows about.
  *
@@ -1471,16 +1464,22 @@ Nevow.Athena.bootstrap = function (pageClassName, clientID) {
     var self = this;
     var pageClass = Divmod.namedAny(pageClassName);
     self.page = pageClass(clientID, Nevow.Athena._createMessageDelivery);
-    self.page.bindEvents(window);
+    Divmod.Base.addToCallStack(
+        window, 'onkeypress', self.page.makeHandler('onkeypress'));
 
-    /* Delay initialization for just a moment so that Safari stops whirling
-     * its loading icon.
-     */
-    setTimeout(function() {
-        Divmod.debug("transport", "starting up");
-        self.page.deliveryChannel.start();
-        Divmod.debug("transport", "started up");
-    }, 1);
+
+    Divmod.Runtime.theRuntime.addLoadEvent(function transportStartup() {
+            Divmod.Runtime.theRuntime.addBeforeUnloadHandler(
+                window, self.page.makeHandler('onbeforeunload'));
+            Divmod.debug("transport", "starting up");
+            self.page.deliveryChannel.start();
+            Divmod.debug("transport", "started up");
+
+            Divmod.debug("widget", "Instantiating live widgets");
+            Nevow.Athena.Widget._pageLoaded = true;
+            Nevow.Athena.Widget._instantiateWidgets();
+            Divmod.debug("widget", "Finished instantiating live widgets");
+        });
 };
 
 /**
