@@ -38,7 +38,7 @@ from formless import iformless, annotate
 def _getPreprocessors(inst):
     """
     Accumulate elements from the sequences bound at the C{preprocessors}
-    attribute on all classes in the inheritence hierarchy of the class of
+    attribute on all classes in the inheritance hierarchy of the class of
     C{inst}.  A C{preprocessors} attribute on the given instance overrides
     all preprocessors from the class inheritance hierarchy.
     """
@@ -178,19 +178,20 @@ class FreeformChildMixin:
 
 
 class ConfigurableMixin(object):
-    """A sane IConfigurable implementation for Fragment and Page.
-    Methods starting with bind_ automatically expose corresponding
-    method names. bind_* should return an IBinding (PropertyBinding
-    or MethodBinding), or, as a shortcut for MethodBinding, a list of
-    twoples like this:
+    """
+    A sane L{IConfigurable} implementation for L{Fragment} and L{Page}. 
 
-    def bind_foo(self, ctx):
-        return [('argName', String()), ('anotherArg', Integer())]
+    Methods starting with C{bind_} automatically expose corresponding method
+    names.  C{bind_*} should return an L{IBinding} (L{PropertyBinding} or
+    L{MethodBinding}), or, as a shortcut for L{MethodBinding}, a C{list} of
+    two-C{tuples} like this::
 
-    def foo(self, argName, anotherArg):
-        assert isinstance(argName, str)
-        assert isinstance(anotherArg, int)
+        def bind_foo(self, ctx):
+            return [('argName', String()), ('anotherArg', Integer())]
 
+        def foo(self, argName, anotherArg):
+            assert isinstance(argName, str)
+            assert isinstance(anotherArg, int)
     """
     implements(iformless.IConfigurable)
 
@@ -363,15 +364,11 @@ def originalFactory(ctx):
 
 
 class Fragment(DataFactory, RenderFactory, MacroFactory, ConfigurableMixin):
-    """A fragment is a renderer that can be embedded in a stan document and
-    hooks its template (from the docFactory) up to its data_ and render_
-    methods, i.e. it remembers itself as the IRendererFactory and IContainer.
+    """
+    This class is deprecated because it relies on context objects
+    U{which are being removed from Nevow<http://divmod.org/trac/wiki/WitherContext>}.
 
-    Fragment primarily serves as the base for Page, Nevow's web resource, but
-    it can be used for more complex rendering. For instance, a fragment might
-    be used to encapsulate the rendering of a complex piece of data where the
-    template is read from disk and contains standard renderers (sequence,
-    mapping etc) and/or custom render methods.
+    @see: L{Element}
     """
     implements(inevow.IRenderer, inevow.IGettable)
 
