@@ -14,11 +14,12 @@ StringIO = cStringIO
 del cStringIO
 from zope.interface import implements
 
-# Sibling Imports
-from twisted.web import error
+try:
+    from twisted.web.resource import NoResource, ForbiddenResource
+except ImportError:
+    from twisted.web.error import NoResource, ForbiddenResource
 from twisted.web.util import redirectTo
 
-# Twisted Imports
 try:
     from twisted.web import http
 except ImportError:
@@ -32,33 +33,44 @@ from twisted.python.runtime import platformType
 from nevow import appserver, dirlist, inevow, rend
 
 
-dangerousPathError = error.NoResource("Invalid request URL.")
+dangerousPathError = NoResource("Invalid request URL.")
 
 def isDangerous(path):
     return path == '..' or '/' in path or os.sep in path
 
 class Data:
-    implements(inevow.IResource)
-
     """
     This is a static, in-memory resource.
     """
+    implements(inevow.IResource)
 
     def __init__(self, data, type, expires=None):
         self.data = data
         self.type = type
         self.expires = expires
 
+
+    def time(self):
+        """
+        Return the current time as a float.
+
+        The default implementation simply uses L{time.time}.  This is mainly
+        provided as a hook for tests to override.
+        """
+        return time.time()
+
+
     def locateChild(self, ctx, segments):
         return appserver.NotFound
 
+
     def renderHTTP(self, ctx):
         request = inevow.IRequest(ctx)
         request.setHeader("content-type", self.type)
         request.setHeader("content-length", str(len(self.data)))
         if self.expires is not None:
             request.setHeader("expires",
-                              http.datetimeToString(time.time() + self.expires))
+                              http.datetimeToString(self.time() + self.expires))
         if request.method == "HEAD":
             return ''
         return self.data
@@ -291,7 +303,7 @@ class File:
         except IOError, e:
             import errno
             if e[0] == errno.EACCES:
-                return error.ForbiddenResource().render(request)
+                return ForbiddenResource().render(request)
             else:
                 raise
 
