@@ -270,7 +270,7 @@ class GuardTestFuncs:
 
     def getGuardPath(self):
         """
-        Return a path to the guard. An empty string if guard is a the root,
+        Return a path to the guard. An empty string if guard is the root,
         otherwise guaranteed to start with a slash and end with a non-slash.
         """
         if not self.guardPath:
@@ -859,58 +859,3 @@ class GuardTest_NotAtRoot_oneLevel(GuardTestSuper, GuardTestFuncs):
 
 class GuardTest_NotAtRoot_manyLevels(GuardTestSuper, GuardTestFuncs):
     guardPath = ['foo', 'bar', 'baz']
-
-class LeakyPage(SillyPage):
-    def renderHTTP(self, context):
-        return "woo"
-
-
-class LeakyRealm:
-    implements(IRealm)
-
-    def requestAvatar(self, avatarId, mind, *interfaces):
-        if avatarId == ANONYMOUS:
-            return inevow.IResource, SillyAnonymous(), lambda: None
-        else:
-            return inevow.IResource, LeakyPage(), lambda: None
-
-
-class LeakTest(GuardTestSuper):
-    def makeRequest(self, sw, p, username):
-        chan = self.createChannel(sw)
-        req = chan.makeFakeRequest(
-            '/__login__?username=%(username)s&password=%(username)s' % {'username': username}
-        ).followAllRedirects()
-        self.assertEquals(req.written.getvalue(), "woo")
-        for i in range(10):
-            req = chan.makeFakeRequest(
-                '/foo/bar/baz/bamf/'
-            ).followAllRedirects()
-
-    def _leaky(self):
-        p = self.createPortal(LeakyRealm)
-        sw = self.createSessionWrapper(p)
-        p.registerChecker(
-            InMemoryUsernamePasswordDatabaseDontUse(
-                test0='test0',
-                test1='test1',
-                test2='test2',
-                test3='test3',
-                test4='test4',
-                test5='test5',
-                test6='test6',
-                test7='test7',
-                test8='test8',
-                test9='test9'),
-            IUsernamePassword)
-        for x in range(10):
-            self.makeRequest(sw, p, 'test%s' % x)
-
-    def test_leak(self):
-        self._leaky()
-
-        ref = [x for x in gc.get_referrers(context.PageContext) if isinstance(x, context.PageContext)]
-        #print ref
-        #import pdb; pdb.Pdb().set_trace()
-
-
