@@ -1,3 +1,9 @@
+# Copyright (c) 2008 Divmod.
+# See LICENSE for details.
+
+"""
+Tests for L{nevow.livepage}.
+"""
 
 from twisted.trial import unittest
 
