@@ -2,6 +2,9 @@
 #  1. make exception renderer work (currently the code is in appserver.py)
 # - srid
 
+import warnings
+warnings.warn("nevow.wsgi is deprecated.", category=DeprecationWarning)
+
 import sys, socket, math, time
 import cgi # for FieldStorage
 import types
@@ -9,6 +12,8 @@ from urllib import unquote, quote
 
 from zope.interface import implements
 
+from twisted.web.http import stringToDatetime
+
 from nevow import context, flat, inevow, util
 from nevow import __version__ as nevowversion
 
